@@ -16,13 +16,6 @@ tarname="latrine-${version}.tar.gz"
 cd ..
 fakeroot tar cvzf $tarname --exclude CVS --exclude .cvsignore --exclude debian latrine-$version
 ln -sf $tarname latrine_$version.orig.tar.gz
-echo -n "Sign $tarname? [y/N] "
-read sign
-if test "$sign" = y; then
-	gpg -ab $tarname
-else
-	echo "No."
-fi
 cd latrine-$version
 if ! grep -iq "AC_INIT.*[${version}]" src/configure.ac; then
 	echo "*** WARNING: version in configure.ac out of date  ***"
@@ -33,9 +26,16 @@ fi
 if grep -iq "^${version}:" TODO; then
 	echo "*** WARNING: current version in TODO file present ***"
 fi
-if ! grep -iq "Project-Id-Version:.* ${version}\\\\n" src/po/de.po; then
-	echo "*** WARNING: version in de.po out of date         ***"
-fi
-if grep -iq "fuzzy" src/po/??.po; then
-	echo "*** WARNING: fuzzy strings in some .po file       ***"
+for i in src/po/??.po; do
+	if grep -iq "fuzzy" $i; then
+		echo "*** WARNING: fuzzy strings in $i   ***"
+	fi
+done
+cd ..
+echo -n "Sign $tarname? [y/N] "
+read sign
+if test "$sign" = y; then
+	gpg -ab $tarname
+else
+	echo "No."
 fi
