@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2004 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -12,8 +12,8 @@
  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02111-1307 USA.
+ * this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+ * St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <charset.h>
 #include <iconv.h>
@@ -33,6 +33,117 @@ static struct {
 	char *to;
 } mapping[2][MAX_KEYMAP];
 
+/* make digraph character
+ */
+inline void make_digraph(wint_t alpha, wint_t *special)
+{
+	switch (alpha) {
+	case 'A': switch (*special) {
+			case '\'': *special = 193; break;
+			case ':' : *special = 196; break;
+	} break;
+	case 'a': switch (*special) {
+			case '\'': *special = 225; break;
+			case ':' : *special = 228; break;
+	} break;
+	case 'C': switch (*special) {
+			case '<' : *special = 268; break;
+	} break;
+	case 'c': switch (*special) {
+			case '<' : *special = 269; break;
+	} break;
+	case 'D': switch (*special) {
+			case '<' : *special = 270; break;
+	} break;
+	case 'd': switch (*special) {
+			case '<' : *special = 271; break;
+	} break;
+	case 'E': switch (*special) {
+			case '\'': *special = 201; break;
+	} break;
+	case 'e': switch (*special) {
+			case '\'': *special = 233; break;
+	} break;
+	case 'I': switch (*special) {
+			case '\'': *special = 205; break;
+	} break;
+	case 'i': switch (*special) {
+			case '\'': *special = 237; break;
+	} break;
+	case 'L': switch (*special) {
+			case '\'': *special = 313; break;
+			case '<' : *special = 317; break;
+	} break;
+	case 'l': switch (*special) {
+			case '\'': *special = 314; break;
+			case '<' : *special = 318; break;
+	} break;
+	case 'N': switch (*special) {
+			case '?' : *special = 209; break;
+			case '<' : *special = 327; break;
+	} break;
+	case 'n': switch (*special) {
+			case '?' : *special = 241; break;
+			case '<' : *special = 328; break;
+	} break;
+	case 'O': switch (*special) {
+			case '\'': *special = 211; break;
+			case '>' : *special = 212; break;
+	} break;
+	case 'o': switch (*special) {
+			case '\'': *special = 243; break;
+			case '>' : *special = 244; break;
+	} break;
+	case 'R': switch (*special) {
+			case '\'': *special = 340; break;
+	} break;
+	case 'r': switch (*special) {
+			case '\'': *special = 341; break;
+	} break;
+	case 'S': switch (*special) {
+			case '<' : *special = 352; break;
+	} break;
+	case 's': switch (*special) {
+			case '<' : *special = 353; break;
+	} break;
+	case 'T': switch (*special) {
+			case '<' : *special = 356; break;
+	} break;
+	case 't': switch (*special) {
+			case '<' : *special = 357; break;
+	} break;
+	case 'U': switch (*special) {
+			case '\'': *special = 218; break;
+	} break;
+	case 'u': switch (*special) {
+			case '\'': *special = 250; break;
+	} break;
+	case 'Y': switch (*special) {
+			case '\'': *special = 221; break;
+	} break;
+	case 'y': switch (*special) {
+			case '\'': *special = 253; break;
+	} break;
+	case 'Z': switch (*special) {
+			case '<' : *special = 381; break;
+	} break;
+	case 'z': switch (*special) {
+			case '<' : *special = 382; break;
+	} break;
+	case '!': switch (*special) {
+			case 'I' : *special = 161; break;
+	} break;
+	case '?': switch (*special) {
+			case 'I' : *special = 191; break;
+	} break;
+	/*
+	default:
+		if (debug)
+			errmsg("FIXME digraph: %d", c);
+	*/
+	}
+}
+
 /* check, whether a given character in a string is a quoted one
  *
  * returns  1: quoted, i.e. odd count of backslashes before
@@ -242,14 +353,19 @@ inline int wcsappend(int i, wchar_t *buffer, wchar_t c, size_t buflen)
  * returns  0: success
  * returns -1: empty string
  */
-inline int wcsbackspace(wchar_t *buffer)
+inline int wcsbackspace(wchar_t *buffer, wchar_t *c)
 {
 	wchar_t *p;
 
+	if (c != NULL)
+		*c = 0;
 	if (buffer == NULL || *buffer == 0L)
 		return -1;
 	for (p = buffer; *p != 0L; p++);
-	*--p = 0L;
+	--p;
+	if (c != NULL)
+		*c = *p;
+	*p = 0L;
 	return 1;
 }
 
