@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2004 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -12,8 +12,8 @@
  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02111-1307 USA.
+ * this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+ * St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <freedict.h>
 #include <charset.h>
@@ -105,15 +105,16 @@ int read_freedict(gzFile hits, struct word *w)
 		do if (read_dict(dict, buf1, BUFSIZE) == -1)
 			return -1;
 		while (*buf1 == 0 && !gzeof(dict));
-		while (strncmp(buf1, "     ", 5) != 0 && *buf1 != '\t' && *buf1 != 0) {
+		while (*buf1 != ' ' && *buf1 != '\t' && *buf1 != 0) {
 			strncat(buf2, buf1, BUFSIZE - strlen(buf2) - 1);
 			if (read_dict(dict, buf1, BUFSIZE) == -1)
 				return -1;
 		}
 		if (assign_word(&w->lang[0], buf2) == -1)
 			return -1;
-		while (strncmp(buf1, "     ", 5) == 0 || *buf1 == '\t') {
-			strncat(buf2, buf1 + (*buf1 == '\t' ? 1 : 5), BUFSIZE - strlen(buf2) - 1);
+		while (*buf1 == ' ' || *buf1 == '\t') {
+			for (s = buf1; *s == ' ' || *s == '\t'; s++);
+			strncat(buf2, s, BUFSIZE - strlen(buf2) - 1);
 			if (read_dict(dict, buf1, BUFSIZE) == -1)
 				return -1;
 		}
