@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2004 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -12,8 +12,8 @@
  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02111-1307 USA.
+ * this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+ * St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #include <charset.h>
 #include <data.h>
@@ -342,9 +342,10 @@ int get_wch(wint_t*);
 static int key_handler(wchar_t *answer)
 {
 	char buf2[BUFSIZE];
-	int r = 0;
-	int ret  = RUNNING;
-	wint_t c;
+	int ret = RUNNING;
+	static wchar_t alpha = 0;
+	static int zdigraph = 0; /* 0: no digraph; 1: digraph possible; 2: digraph active */
+	wint_t c, r;
 
 	memset(buf2, 0, BUFSIZE);
 	nodelay(stdscr, 0);
@@ -358,20 +359,24 @@ static int key_handler(wchar_t *answer)
 				update_phrase();
 				break;
 			case KEY_BACKSPACE:
-				wcsbackspace(answer);
+				wcsbackspace(answer, &alpha);
+				zdigraph = (zdigraph == 1) ? 2 : 0;
 				break;
 			case KEY_LEFT:
 				phrase_offset--;
+				zdigraph = 0;
 				update_phrase();
 				break;
 			case KEY_RIGHT:
 				phrase_offset++;
+				zdigraph = 0;
 				update_phrase();
 				break;
 			case KEY_F1:
 				break;
 			case KEY_F2:
 				reload_dict();
+				zdigraph = 0;
 				ret = NEW_WORD;
 				break;
 			case KEY_F3:
@@ -391,6 +396,7 @@ static int key_handler(wchar_t *answer)
 			case KEY_ESC:
 				exit(0);
 			case KEY_RETURN:
+				zdigraph = 0;
 				ret = CONTINUE;
 				break;
 			case KEY_CTRL_L:
@@ -399,15 +405,20 @@ static int key_handler(wchar_t *answer)
 				break;
 			case KEY_CTRL_U:
 				*answer = 0L;
+				zdigraph = 0;
 				break;
 			case KEY_TAB:
+				zdigraph = 0;
 				ret = NEW_WORD;
 				break;
 			default:
+				if (digraph && (zdigraph == 2))
+					make_digraph(alpha, &c);
 				if (wcsappend(reverse ? 0 : 1, answer, c, BUFSIZE) == -1) {
-					wcsbackspace(answer);
+					wcsbackspace(answer, NULL);
 					wcsappend(reverse ? 0 : 1, answer, c, BUFSIZE);
 				}
+				zdigraph = 1;
 			}
 			break;
 		}
@@ -477,11 +488,11 @@ void running(void)
 		while ((i = key_handler(answer)) == RUNNING);
 		if (i != CONTINUE)
 			continue;
-		bkgdset(COLOR_PAIR(COLOR_BACK));
 		i = check(answer, p->lang[reverse ? 0 : 1]); /* may destroy answer */
 		update_counter(i ? 1 : -1);
 		update_word(p, i);
 		snprintf(line1, BUFSIZE, "%s: %s -> %s", i ? correct : wrong, p->lang[reverse ? 1 : 0], p->lang[reverse ? 0 : 1]);
+		bkgdset(COLOR_PAIR(COLOR_BACK));
 		mvaddnstr(16, LEFT, line1, sx - LEFT);
 		clrtoeol();
 		strcpy(line2, history);
